% Intelligence artificielle et enseignement
% Orestis Malaspinas et Marc Gay-Balmaz
% Hepia, 03.06.2024

# Introduction aux modèles génératifs

\Huge Introduction aux modèles génératifs (LLMs)

# Qu'est-ce que l'IA?

* Ensemble de techniques visant à simuler l'intelligence humaine:
    * Moteurs de recherche,
    * Voitures autonomes,
    * Compréhension du langage naturel,
    * Chatbot,
    * Génération d'images, ...

. . .

* On se limite aux IA **génératives** et en particuliers aux "Large Language Models" (LLMs).

# Que sont les IA générative et les LLMs

## Définitions

* LLM: Un modèle de langage qui permet de générer du texte et d'effectuer des tâches complexes comme la classification. (*Wikipedia*)
* IA générative: intelligence artificielle capable de générer un contenu ne se trouvant pas dans son ensemble d'entraînement. (*Wikipedia aussi*)

. . .

## Remarque

* Tout ce qui est généré n'est pas nouveau...

# Fonctionnement des LLMs (1/4)

## Problème de base à résoudre

* Soit une suite de mots donnée (prompt):

. . .

*Orestis donne une présentation sur*

* Trouver le mot suivant le plus probable:

. . .

*Orestis donne une présentation sur* **l'intelligence**

* Puis le mot suivant:

. . .

*Orestis donne un cours sur l'intelligence* **artificielle**.

* Et ainsi de suite.

. . .

## En d'autres termes...

***C'est un auto-compléteur de texte!***

# Fonctionnement des LLMs (2/4)

## De quoi dépend le "mot suivant"?

* Des mots qui précèdent directement,
* Du contexte général.
* Doit avoir la bonne forme (orthographe, grammaire, etc)

. . .

## Problème difficile

* Problème complexe à **formaliser**/**modéliser**, donc à **implémenter** informatiquement (malgré beaucoup d'efforts).

# Fonctionnement des LLMs (3/4)

## Solution pour les LLMs actuels (GPT-etc)

0. On donne un "pré-prompt": phrases qui donnent un contexte.
1. On décompose le prompt en "tokens" (mots):
    * Orestis - nom propre
    * donne - verbe
    * une - pronom indéfini
    * présentation - nom
    * sur - préposition
2. Un réseau de neurones prédit le mot suivant le plus *probable*.
3. Mesures de protection pour empêcher les fuites de données (pas à proprement parler dans les LLMs)

. . .

## Comment trouver les paramètres?

# Fonctionnement des LLMs (4/4)

## Fixer les paramètres

* On *entraîne* le réseau de neurones sur des gigantesques ensembles de données (Wikipedia, Github, etc.):
    * Nécessaire pour l'apprentissage des patterns (formes).
    * Donne des résultats impressionnants: complexes et élégants.

. . .

* Problématiques:
    * Impossible de vérifier la qualité de tout l'ensemble d'entraînement.
    * Possède les biais de l'ensemble d'entraînement.
    * Pas de nouveautés une fois entraîné.
    * Sécurité faible.
    * Droits d'auteur.

# Quelques chiffres

## Paramètres

* Dalle-2: $3.5\cdot 10^{9}$ paramètres
* Gemini: $1.6\cdot 10^{12}$ paramètres
* GPT-4: $1.7\cdot 10^{12}$ paramètres

. . .

## Performances

* Performances "humaines" pour beaucoup d'applications (niveau basique):
    * classification d'images
    * mathématiques
    * compréhension de texte
    * ...

# Les modèles génératifs marchent bien

## Efficacité

* Résultats très bien écrits (orthographe, grammaire, style),
* Arrive à imiter le "style" d'auteurs et autrices,
* Textes générés sont généralement **très convaincants**.

. . .

## Bons cas d'usages

* Reformuler un texte
* Changer le "ton" d'un texte en gardant le sens
* Corriger le style et l'orthographe

## Résumer

* Obtenir les points principaux d'un texte

. . .

## Attention

* Dans **tous les cas** il est **impossible** d'avoir une garantie que le contenu est **équivalent** à celui de départ.

# Cas concert

\Huge Pour les enseignant/e/s

# Cas d'utilisation concret (enseignant/e/s)

* Utilisation de `Copilot` pour créer un cours d'introduction à l'algorithmique.
* Questions posées:
    * Créer un syllabus pour 14 séance de 135min chacune (3 périodes).
    * Créer le contenu pour une séance données en 1e année à hepia
* Comparaison avec la création d'un cours classique.

# Cas d'utilisation: syllabus

\footnotesize

**Leçon 1 : Introduction à l'algorithmique**

* Définition de l'algorithmique et histoire.
* Exemples d'algorithmes simples.

**Leçon 2 : Notions de base**

* Termes clés et concepts fondamentaux.
* Exercices pratiques.

**Leçon 3 : Complexité algorithmique**

* Analyse de la complexité en temps et en espace.
* Exemples et exercices.

**Leçon 4 : Tri et recherche**

* Algorithmes de tri et de recherche.
* Implémentation et comparaison.

**Leçon 5 : Structures de données**

* Listes, piles, files, arbres.
* Exemples concrets.

# Cas d'utilisation: séance (1/5)

## Introduction à la Complexité des Algorithmes

L'analyse de la complexité des algorithmes est essentielle pour évaluer leur performance en termes de temps d'exécution. 
Elle nous permet de comprendre comment le temps nécessaire pour résoudre un problème évolue en fonction de la taille des données traitées. 
Dans ce domaine, deux aspects sont particulièrement importants : la **complexité temporelle** et la **complexité spatiale**.

## Complexité Temporelle

La complexité temporelle mesure le nombre d'opérations élémentaires (comme les additions, les comparaisons, les affectations, etc.) 
effectuées par un algorithme en fonction de la taille des données en entrée. 
Plus précisément, nous nous intéressons au comportement asymptotique de l'algorithme lorsque la taille des données tend vers l'infini.

. . .

**Note :** pas mal du tout.

# Cas d'utilisation: séance (2/5)

### Notation "Grand O"

La notation "grand O" (ou "O-notation") est couramment utilisée pour exprimer la complexité temporelle. 
Elle permet de décrire la croissance relative du temps d'exécution en fonction de la taille des données. 
Par exemple, si un algorithme a une complexité en "O(n)", cela signifie que le temps d'exécution est linéaire par rapport à la taille des données.

. . .

**Note :** Manque de précision: on sait pas ce qu'est **n**, ni ce qu'est la *taille des données*.

# Cas d'utilisation : séance (3/5)

\footnotesize

## Exemple Simple

Considérons un algorithme qui calcule la somme des éléments d'un tableau d'entiers. Voici un exemple en pseudo-code :

```C
Début
  Somme <-- 0  // début et la boucle "Pour" = t1
  Pour chaque élément T[i] du tableau // comparaison dans la boucle = t2
    Somme <-- Somme + T[i] // addition dans la boucle = t3
  FinPour // incrémentation de l'indice i = t4
Fin
```

Le temps d'exécution total est donné par :

$$ t(n) = t1 + \sum_{i=1}^{n} (t2 + t3 + t4) + t2 $$

En supposant que `t1, t2, t3, t4` sont des constantes (indépendantes de `n`), nous pouvons dire que l'algorithme est asymptotiquement linéaire en `n`. 
Autrement dit, lorsque `n` tend vers l'infini, le temps d'exécution est proportionnel à `n`.

. . .

**Note :** Discutable: la formule est fausse ou imprécise manque un `t4`.

# Cad d'utilisation : séance (4/5)

Il est important de noter que cette évaluation en "pire des cas" ignore la nature des données (par exemple, si le tableau est trié ou non). 
Cependant, elle nous donne une idée générale de la performance de l'algorithme.

. . .

**Note :** Cette remarque n'a rien à faire là et n'est pas du tout reliée à ce qui précède.

# Cas d'utilisation: séance (5/5)

## Bibliographie

Source : conversation avec Copilot, 6/2/2024

1. Complexité des Algorithmes A) Introduction. <https://lipn.univ-paris13.fr/~banderier/P13/Algo/cours_complexite.pdf>.
2. Comprendre la complexité des algorithmes. <https://bing.com/search?q=introduction+%c3%a0+la+complexit%c3%a9+d%27un+algorithme+avec+un+exemple+simple>.
3. Complexité d’un algorithme – l'Informatique, c'est fantastique. <https://info.blaisepascal.fr/nsi-complexite-dun-algorithme/>.
4. Comprendre la complexité des algorithmes. <https://www.sfeir.dev/front/comprendre-la-complexite-des-algorithmes/>.
5. Introduction à la complexité algorithmique - Université de Limoges. <https://www.irem.unilim.fr/OLD/fileadmin/documents/2015_01_04-Introduction_complexite_algorithmique.pdf>.
6. undefined. <https://bing.com/search?q=>.

# Et sans IA générative?

## Procédure classique

1. Recherche bibliographique (anciens cours suivis, cours existants dans l'école, cours d'autres écoles, livres, ...).
2. Création d'un syllabus réaliste basé sur **l'expérience acquise** dans le domaine.
3. Création de zéro ou reformulation d'un contenu **appropriation**.
4. Citation des **sources** et des **références** pour les élèves.

. . .

## Reprendre du contenu sans correction profondes?

* Similaire à lire un livre contenant des erreurs et approximations.

# Utilisation par les élèves

\Huge Utilisation par les élèves

# Résolution de problèmes

## Cadre

* Exercices courts
* Travaux pratiques
* Rendus écrits (rapport, mémoire)

. . .

## Utilisation typique

* Pour un retour / correction rapide
* Pour se lancer sur un problème
* Pour obtenir des informations sur un sujet
* Corriger orthographe, grammaire, et style

. . .

## Comportement typique

* Tout copier-coller dans le prompt.

# Effet sur l'apprentissage: risques

* L'utilisation intensive de l'IA est mauvaise pour la consolidation des apprentissages:
    * Pas de travail reformulation/réinterprétation,
    * Pas besoin de comprendre les questions,
    * Pas besoin de comprendre les réponses,
    * Globalement: très grande passivité des élèves.

. . .

* Empêche d'offrir des références solides et reproductibles.

. . .

* Peut offrir un retour rapide ou aider au démarrage, pour autant que... les réponses soient **justes**.

# Fraude et probité (1/2)

## Détection de la fraude

* Détecteurs "d'IA" marchent à 60\% (au mieux)[^1]. 
* Détecteurs de plagiat / copie marchent bien!
* Ce qui marche le mieux est le style **toujours le même** de ces outils.

[^1]: Source: [Artificial Intelligence Index Report](https://aiindex.stanford.edu/wp-content/uploads/2024/05/HAI_AI-Index-Report-2024.pdf)

# Fraude et probité (2/2)

## Citation

* On recommande de citer l'IA utilisée et la date. C'est **insuffisant**:
    * On devrait donner l'ensemble des prompts de la session,
    * L'historique *complète* d'utilisation (cookies),
    * On contrôle pas le modèle exact, l'ensemble d'entraînement, le pré-prompt, etc.
    * La réponse donnée peut être un plagiat.

. . .

Copilot: "Unlike **solving the Navier–Stokes equations directly**, LBM operates **on a lattice**, simulating **fluid density** through **streaming and collision processes**."

Wikipedia: "Instead of **solving the Navier–Stokes equations directly**, a **fluid density** **on a lattice** is simulated with **streaming and collision** (relaxation) **processes**."

# Études sur l'efficacité des modèles pour l'informatique

## Biais

* Sur des questions populaires: 50% des réponses sont fausses[^2]
* Problème: 30\% des sondés croient la mauvaise réponse plutôt que la bonne (biais dû au style).

[^2]: Source: [Is Stack Overflow Obsolete?](https://dl.acm.org/doi/pdf/10.1145/3613904.3642596)

# Le coût des modèles génératifs

\Huge Coût des modèles génératifs

# Coût computationnel: exponentiel[^1]

![](figs/training_compute_notable.png)

**Comparaison :** 10 ans du plus puissant super calculateur Suisse (no 6 mondial).

# Coût économique: exponentiel[^1]

![](figs/training_cost_notable.png)

**Comparaison :** 10% du budget annuel de l'EPFL.

# Coût écologique d'entraînement: exponentiel[^1]

![](figs/carbon_training.png)

**Comparaison :** 50 Suisses pendant 1 an pour GPT-3.

# Coût écologique d'inférence: exponentiel[^1]

![](figs/carbon_inference.png)

**Comparaison :** Une recherche Google vaut 1g, une impression de mail 10g.

# Conclusion et avenir

\Huge Conclusion et avenir

# Conclusion (1/2)

* Les modèles génératifs ont une efficacité impressionnante,
* Ils ont néanmoins *souvent* tort, tout en donnant à l'utilisateur/trice une grande confiance dans la réponse.
* Le coût-bénéfice est à évaluer:
    * Quels bénéfices pour les élèves?
    * Quels bénéfices pour les enseignantes et enseignants?
    * Le coût économique/écologique est énorme et explose **exponentiellement**.

# Conclusion (2/2)

## Mon avis

Ces modèles sont impressionnants, mais d'une utilité limitée pour l'enseignement et l'apprentissage:

*Il faut être un expert pointu pour les utiliser efficacement et détecter les fautes commises.*

## Mon conseil

Si vous ne pouvez pas dire si un contenu est correct en *secondes*, n'utilisez pas une IA générative.

## Non ce n'est pas pareil que...

* Copier Wikipedia, Stack Overflow, etc. Tous ces sites ont un système **d'experts**.

# L'avenir

* L'avenir est très incertain: 
    * Évolution de ces modèles (+efficaces? +sûrs? -énergivores?)
    * Évolution de la législation (meilleure protection des usagers? des créateurs?)
        * [Nouvelle loi européenne](https://vcsi.org/eu-ai-act-comprehensive-regulation/)
* A suivre donc, mais prudence...

# La fin

\Huge 

Merci de votre attention.

Questions?

<!-- # Coûts énergétiques -->
<!---->
<!-- ## Estimations -->
<!---->
<!-- * GPT-3: 1GWh pour son entraînement (50 genevois pendant un an) -->
<!-- * GPT-4: 50GWh pour son entraînement (2500 genevois pendant un an) -->
<!-- * Chaque mois, ChatGPT consomme autant que 30'000 genevois (estimations) -->
<!---->
<!-- # Souhaits IA -->
<!---->
<!-- ![](figs/ai_laundry.png) -->
